aboutsummaryrefslogtreecommitdiffstats
path: root/common/rfb/SConnection.h
diff options
context:
space:
mode:
authorPierre Ossman <ossman@cendio.se>2024-09-02 20:41:47 +0200
committerPierre Ossman <ossman@cendio.se>2024-09-02 20:41:47 +0200
commitda1adb5073dad2ae9cd968dc6f213c9f027c46ce (patch)
treefb6ce46052179f2ab5e139fa1c65363a00fb14d1 /common/rfb/SConnection.h
parent2e3347768d3d19852e2c575d1b9425e23d6efa87 (diff)
downloadtigervnc-da1adb5073dad2ae9cd968dc6f213c9f027c46ce.tar.gz
tigervnc-da1adb5073dad2ae9cd968dc6f213c9f027c46ce.zip
Remove ConnFailedException
There were more unclear usage of this exception class, and since nothing catches it it is very unclear what the purpose is. Go ahead and just remove it. Follow-up to bcaaea7.
Diffstat (limited to 'common/rfb/SConnection.h')
-rw-r--r--common/rfb/SConnection.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/common/rfb/SConnection.h b/common/rfb/SConnection.h
index 46b427ed..0a11f67b 100644
--- a/common/rfb/SConnection.h
+++ b/common/rfb/SConnection.h
@@ -216,10 +216,10 @@ namespace rfb {
int32_t getPreferredEncoding() { return preferredEncoding; }
protected:
- // throwConnFailedException() prints a message to the log, sends a conn
- // failed message to the client (if possible) and throws a
- // ConnFailedException.
- void throwConnFailedException(const char* format, ...)
+ // failConnection() prints a message to the log, sends a connection
+ // failed message to the client (if possible) and throws an
+ // Exception.
+ void failConnection(const char* format, ...)
__attribute__((__format__ (__printf__, 2, 3)));
void setState(stateEnum s) { state_ = s; }